# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/neolix_edu.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/neolix_edu.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/canbus/proto/neolix_edu.proto\x12\rapollo.canbus\"\xc9\x02\n\x12\x41\x65\x62_systemstate_11\x12\x11\n\taeb_state\x18\x01 \x01(\x05\x12\x16\n\x0e\x61\x65\x62_brakestate\x18\x02 \x01(\x08\x12\x11\n\tfaultrank\x18\x03 \x01(\x05\x12\x1a\n\x12\x63urrenttemperature\x18\x04 \x01(\x05\x12\x13\n\x0bpas_f1_stop\x18\x05 \x01(\x08\x12\x13\n\x0bpas_f2_stop\x18\x06 \x01(\x08\x12\x13\n\x0bpas_f3_stop\x18\x07 \x01(\x08\x12\x13\n\x0bpas_f4_stop\x18\x08 \x01(\x08\x12\x13\n\x0bpas_b1_stop\x18\t \x01(\x08\x12\x13\n\x0bpas_b2_stop\x18\n \x01(\x08\x12\x13\n\x0bpas_b3_stop\x18\x0b \x01(\x08\x12\x13\n\x0bpas_b4_stop\x18\x0c \x01(\x08\x12\x1c\n\x14\x61\x65\x62_livecounter_rear\x18\r \x01(\x05\x12\x13\n\x0b\x61\x65\x62_cheksum\x18\x0e \x01(\x05\"\xd6\x04\n\x1eVcu_vehicle_fault_response_201\x12$\n\x1cvehicle_error_indicationsvcu\x18\x01 \x01(\x05\x12\x1d\n\x15\x62rake_system_errorehb\x18\x02 \x01(\x05\x12\x11\n\teps_error\x18\x03 \x01(\x05\x12\x13\n\x0bmotor_error\x18\x04 \x01(\x05\x12\x11\n\tepb_error\x18\x05 \x01(\x05\x12%\n\x1dhigh_voltage_battery_errorbcu\x18\x06 \x01(\x05\x12(\n automode_exit_reason_losscommuni\x18\x07 \x01(\x08\x12(\n automode_exit_reason_reqsignalno\x18\x08 \x01(\x08\x12&\n\x1e\x61utomode_exit_reason_low_power\x18\t \x01(\x08\x12%\n\x1d\x61utomode_exit_reason_highvolt\x18\n \x01(\x08\x12(\n automode_exit_reason_vehicle_flt\x18\x0b \x01(\x08\x12(\n automode_exit_reason_press_emerg\x18\x0c \x01(\x08\x12(\n automode_exit_reason_press_remot\x18\r \x01(\x08\x12(\n automode_exit_reason_pdu_control\x18\x0e \x01(\x08\x12\"\n\x1avcu_faultrept_alivecounter\x18\x0f \x01(\x05\x12\x1e\n\x16vcu_faultrept_checksum\x18\x10 \x01(\x05\"\x99\x02\n\x13Vcu_powerstatus_214\x12\x15\n\rvcu_powermode\x18\x01 \x01(\x05\x12\x1a\n\x12vcu_powermodevalid\x18\x02 \x01(\x05\x12%\n\x1dreplacebatterystateindication\x18\x03 \x01(\x08\x12\x1c\n\x14\x66orbidden_aeb_signal\x18\x04 \x01(\x08\x12\"\n\x1a\x62\x63u_chargedischargecurrent\x18\x05 \x01(\x01\x12 \n\x18\x62\x63u_batt_internalvoltage\x18\x06 \x01(\x01\x12#\n\x1bvcu_driverinfo_alivecounter\x18\x07 \x01(\x05\x12\x1f\n\x17vcu_driverinfo_checksum\x18\x08 \x01(\x05\"\xd1\x01\n\x1a\x41\x64s_light_horn_command_310\x12 \n\x18turn_right_light_command\x18\x01 \x01(\x08\x12\x1f\n\x17turn_left_light_command\x18\x02 \x01(\x08\x12\x14\n\x0chorn_command\x18\x03 \x01(\x08\x12\x14\n\x0c\x62\x65\x61m_command\x18\x04 \x01(\x05\x12#\n\x1b\x61uto_drivercmd_alivecounter\x18\x05 \x01(\x05\x12\x1f\n\x17\x61uto_drivercmd_checksum\x18\x06 \x01(\x05\"\xce\x01\n\x14\x41\x64s_brake_command_46\x12\x14\n\x0c\x64rive_enable\x18\x01 \x01(\x08\x12\x1a\n\x12\x61uto_brake_command\x18\x02 \x01(\x05\x12\x1c\n\x14\x61uto_parking_command\x18\x03 \x01(\x08\x12 \n\x18\x65pb_rampauxiliarycommand\x18\x04 \x01(\x08\x12#\n\x1b\x61uto_drivercmd_alivecounter\x18\x05 \x01(\x05\x12\x1f\n\x17\x61uto_drivercmd_checksum\x18\x06 \x01(\x05\"\xc0\x04\n\x13Vcu_brake_report_47\x12\x19\n\x11\x62rake_enable_resp\x18\x01 \x01(\x08\x12S\n\x11\x63ontrol_mode_resp\x18\x02 \x01(\x0e\x32\x38.apollo.canbus.Vcu_brake_report_47.Control_mode_respType\x12\x1c\n\x14vcu_real_brake_valid\x18\x03 \x01(\x08\x12\x16\n\x0evcu_real_brake\x18\x04 \x01(\x05\x12\x1f\n\x17vcu_real_parking_status\x18\x05 \x01(\x05\x12\x1e\n\x16vcu_real_parking_valid\x18\x06 \x01(\x08\x12\x1f\n\x17rampauxiliaryindication\x18\x07 \x01(\x08\x12\x14\n\x0cvehicleslope\x18\x08 \x01(\x01\x12\"\n\x1avcu_brakerept_alivecounter\x18\t \x01(\x05\x12\x1e\n\x16vcu_brakerept_checksum\x18\n \x01(\x05\"\xc6\x01\n\x15\x43ontrol_mode_respType\x12\x1d\n\x19\x43ONTROL_MODE_RESP_STANDBY\x10\x00\x12 \n\x1c\x43ONTROL_MODE_RESP_AUTO_DRIVE\x10\x01\x12\x1f\n\x1b\x43ONTROL_MODE_RESP_NET_DRIVE\x10\x02\x12$\n CONTROL_MODE_RESP_REMOTE_CONTROL\x10\x03\x12%\n!CONTROL_MODE_RESP_EMERGENCY_BRAKE\x10\x04\"\x94\x04\n\x11Vcu_eps_report_57\x12\x19\n\x11\x64rive_enable_resp\x18\x01 \x01(\x08\x12Q\n\x11\x63ontrol_mode_resp\x18\x02 \x01(\x0e\x32\x36.apollo.canbus.Vcu_eps_report_57.Control_mode_respType\x12\x16\n\x0evcu_eps_report\x18\x03 \x01(\x08\x12\x16\n\x0evcu_real_angle\x18\x04 \x01(\x01\x12\x1c\n\x14vcu_real_angle_valid\x18\x05 \x01(\x08\x12\x1e\n\x16vcu_target_angle_valid\x18\x06 \x01(\x08\x12\x18\n\x10vcu_target_angle\x18\x07 \x01(\x01\x12!\n\x19vcu_eps_rept_alivecounter\x18\x08 \x01(\x05\x12\x1d\n\x15vcu_eps_rept_checksum\x18\t \x01(\x05\"\xc6\x01\n\x15\x43ontrol_mode_respType\x12\x1d\n\x19\x43ONTROL_MODE_RESP_STANDBY\x10\x00\x12 \n\x1c\x43ONTROL_MODE_RESP_AUTO_DRIVE\x10\x01\x12\x1f\n\x1b\x43ONTROL_MODE_RESP_NET_DRIVE\x10\x02\x12$\n CONTROL_MODE_RESP_REMOTE_CONTROL\x10\x03\x12%\n!CONTROL_MODE_RESP_EMERGENCY_BRAKE\x10\x04\"\x8b\x01\n\x12\x41\x64s_eps_command_56\x12\x14\n\x0c\x64rive_enable\x18\x01 \x01(\x08\x12\x19\n\x11\x61uto_target_angle\x18\x02 \x01(\x01\x12#\n\x1b\x61uto_drivercmd_alivecounter\x18\x03 \x01(\x05\x12\x1f\n\x17\x61uto_drivercmd_checksum\x18\x04 \x01(\x05\"\xef\x02\n\x14\x41\x64s_drive_command_50\x12\x14\n\x0c\x64rive_enable\x18\x01 \x01(\x08\x12V\n\x12\x61uto_shift_command\x18\x02 \x01(\x0e\x32:.apollo.canbus.Ads_drive_command_50.Auto_shift_commandType\x12\x19\n\x11\x61uto_drive_torque\x18\x03 \x01(\x01\x12#\n\x1b\x61uto_drivercmd_alivecounter\x18\x04 \x01(\x05\x12\x1f\n\x17\x61uto_drivercmd_checksum\x18\x05 \x01(\x05\"\x87\x01\n\x16\x41uto_shift_commandType\x12\x18\n\x14\x41UTO_SHIFT_COMMAND_N\x10\x00\x12\x18\n\x14\x41UTO_SHIFT_COMMAND_D\x10\x01\x12\x18\n\x14\x41UTO_SHIFT_COMMAND_R\x10\x02\x12\x1f\n\x1b\x41UTO_SHIFT_COMMAND_RESERVED\x10\x03\"\xcb\x05\n\x13Vcu_drive_report_52\x12\x19\n\x11\x64rive_enable_resp\x18\x01 \x01(\x08\x12S\n\x11\x63ontrol_mode_resp\x18\x02 \x01(\x0e\x32\x38.apollo.canbus.Vcu_drive_report_52.Control_mode_respType\x12M\n\x0evcu_real_shift\x18\x03 \x01(\x0e\x32\x35.apollo.canbus.Vcu_drive_report_52.Vcu_real_shiftType\x12\x1c\n\x14vcu_real_shift_valid\x18\x04 \x01(\x08\x12\x1d\n\x15vcu_real_torque_valid\x18\x05 \x01(\x08\x12\x17\n\x0fvcu_real_torque\x18\x06 \x01(\x01\x12\x1d\n\x15vcu_limitedtorquemode\x18\x07 \x01(\x08\x12\"\n\x1avcu_driverept_alivecounter\x18\x08 \x01(\x05\x12\x1e\n\x16vcu_driverept_checksum\x18\t \x01(\x05\"\xc6\x01\n\x15\x43ontrol_mode_respType\x12\x1d\n\x19\x43ONTROL_MODE_RESP_STANDBY\x10\x00\x12 \n\x1c\x43ONTROL_MODE_RESP_AUTO_DRIVE\x10\x01\x12\x1f\n\x1b\x43ONTROL_MODE_RESP_NET_DRIVE\x10\x02\x12$\n CONTROL_MODE_RESP_REMOTE_CONTROL\x10\x03\x12%\n!CONTROL_MODE_RESP_EMERGENCY_BRAKE\x10\x04\"s\n\x12Vcu_real_shiftType\x12\x14\n\x10VCU_REAL_SHIFT_N\x10\x00\x12\x14\n\x10VCU_REAL_SHIFT_D\x10\x01\x12\x14\n\x10VCU_REAL_SHIFT_R\x10\x02\x12\x1b\n\x17VCU_REAL_SHIFT_RESERVED\x10\x03\"{\n\x11\x41\x64s_diagnosis_628\x12\x11\n\tfaultrank\x18\x01 \x01(\x05\x12\x17\n\x0f\x61\x64\x61s_fault_code\x18\x02 \x01(\x05\x12\x1c\n\x14\x61\x64\x61s_softwareversion\x18\x03 \x01(\x05\x12\x1c\n\x14\x61\x64\x61s_hardwareversion\x18\x04 \x01(\x05\"&\n\nVcu_nm_401\x12\x18\n\x10vcu_sleepcommand\x18\x01 \x01(\x08\"\xa0\x05\n\x1dVcu_vehicle_status_report_101\x12\x19\n\x11\x64rive_enable_resp\x18\x01 \x01(\x08\x12#\n\x1bvcu_highvoltagecircuitstate\x18\x02 \x01(\x08\x12\x1e\n\x16vcu_dcdc_enabledstates\x18\x03 \x01(\x08\x12]\n\x11\x63ontrol_mode_resp\x18\x04 \x01(\x0e\x32\x42.apollo.canbus.Vcu_vehicle_status_report_101.Control_mode_respType\x12\x19\n\x11vcu_vehicle_speed\x18\x05 \x01(\x01\x12(\n vcu_lowbatterychargingfunctionst\x18\x06 \x01(\x05\x12\x17\n\x0fvcu_display_soc\x18\x07 \x01(\x05\x12\x17\n\x0fvcu_motor_speed\x18\x08 \x01(\x01\x12\x1b\n\x13vcu_motor_direction\x18\t \x01(\x05\x12\x1d\n\x15vcu_motor_speed_valid\x18\n \x01(\x08\x12#\n\x1bvcu_statusrept_alivecounter\x18\x0b \x01(\x05\x12\x1f\n\x17vcu_statusrept_checksum\x18\x0c \x01(\x05\"\xc6\x01\n\x15\x43ontrol_mode_respType\x12\x1d\n\x19\x43ONTROL_MODE_RESP_STANDBY\x10\x00\x12 \n\x1c\x43ONTROL_MODE_RESP_AUTO_DRIVE\x10\x01\x12\x1f\n\x1b\x43ONTROL_MODE_RESP_NET_DRIVE\x10\x02\x12$\n CONTROL_MODE_RESP_REMOTE_CONTROL\x10\x03\x12%\n!CONTROL_MODE_RESP_EMERGENCY_BRAKE\x10\x04\"\xb9\x01\n\x1dVcu_vehicle_info_response_502\x12(\n vehicle_softwareversion_indicati\x18\x01 \x01(\x05\x12\x0f\n\x07project\x18\x02 \x01(\x05\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\x05\x12\x0c\n\x04year\x18\x04 \x01(\x05\x12\r\n\x05month\x18\x05 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x06 \x01(\x05\x12\x1d\n\x15vehicle_serial_number\x18\x07 \x01(\x05\"N\n\x12\x41\x65\x62_diagnosis1_626\x12\x1b\n\x13\x61\x65\x62_softwareversion\x18\x01 \x01(\x01\x12\x1b\n\x13\x61\x65\x62_hardwareversion\x18\x02 \x01(\x01\"(\n\x10\x41\x65\x62_diagresp_718\x12\x14\n\x0c\x61\x65\x62_diagresp\x18\x01 \x01(\x08\"\xc6\x01\n\x10Pas_1st_data_311\x12\x14\n\x0cpasdistance4\x18\x01 \x01(\x01\x12\x14\n\x0cpasdistance3\x18\x02 \x01(\x01\x12\x15\n\rpas_f1_status\x18\x03 \x01(\x08\x12\x15\n\rpas_f2_status\x18\x04 \x01(\x08\x12\x15\n\rpas_f3_status\x18\x05 \x01(\x08\x12\x15\n\rpas_f4_status\x18\x06 \x01(\x08\x12\x14\n\x0cpasdistance2\x18\x07 \x01(\x01\x12\x14\n\x0cpasdistance1\x18\x08 \x01(\x01\"\xc6\x01\n\x10Pas_2nd_data_312\x12\x15\n\rpas_b1_status\x18\x01 \x01(\x08\x12\x15\n\rpas_b2_status\x18\x02 \x01(\x08\x12\x15\n\rpas_b3_status\x18\x03 \x01(\x08\x12\x15\n\rpas_b4_status\x18\x04 \x01(\x08\x12\x14\n\x0cpasdistance1\x18\x05 \x01(\x01\x12\x14\n\x0cpasdistance2\x18\x06 \x01(\x01\x12\x14\n\x0cpasdistance3\x18\x07 \x01(\x01\x12\x14\n\x0cpasdistance4\x18\x08 \x01(\x01\"\xea\x01\n\x14\x41\x65\x62_wheelimpulse_355\x12\x11\n\tflimpulse\x18\x01 \x01(\x01\x12\x16\n\x0e\x66limpulsevalid\x18\x02 \x01(\x08\x12\x11\n\tfrimpulse\x18\x03 \x01(\x01\x12\x16\n\x0e\x66rimpulsevalid\x18\x04 \x01(\x08\x12\x11\n\trlimpulse\x18\x05 \x01(\x01\x12\x16\n\x0erlimpulsevalid\x18\x06 \x01(\x08\x12\x11\n\trrimpulse\x18\x07 \x01(\x01\x12\x16\n\x0errimpulsevalid\x18\x08 \x01(\x08\x12\x14\n\x0c\x61livecounter\x18\t \x01(\x01\x12\x10\n\x08\x63hecksum\x18\n \x01(\x01\"\xee\x01\n\x16\x41\x65\x62_rearwheelspeed_354\x12\x1b\n\x13wheelspeed_rl_valid\x18\x01 \x01(\x08\x12\x15\n\rwheelspeed_rl\x18\x02 \x01(\x01\x12\x1b\n\x13wheelspeed_rr_valid\x18\x03 \x01(\x08\x12\x15\n\rwheelspeed_rr\x18\x04 \x01(\x01\x12\x1c\n\x14wheelspeed_rl_direct\x18\x05 \x01(\x01\x12\x1c\n\x14wheelspeed_rr_direct\x18\x06 \x01(\x01\x12\x19\n\x11\x61livecounter_rear\x18\x07 \x01(\x01\x12\x15\n\rchecksum_rear\x18\x08 \x01(\x01\"\xbd\x02\n\x17\x41\x65\x62_frontwheelspeed_353\x12\x19\n\x11vehiclespeedvalid\x18\x01 \x01(\x08\x12\x14\n\x0cvehiclespeed\x18\x02 \x01(\x01\x12\x19\n\x11vehiclerealdirect\x18\x03 \x01(\x01\x12\x1b\n\x13wheelspeed_fl_valid\x18\x04 \x01(\x08\x12\x15\n\rwheelspeed_fl\x18\x05 \x01(\x01\x12\x1b\n\x13wheelspeed_fr_valid\x18\x06 \x01(\x08\x12\x15\n\rwheelspeed_fr\x18\x07 \x01(\x01\x12\x1c\n\x14wheelspeed_fl_direct\x18\x08 \x01(\x01\x12\x1c\n\x14wheelspeed_fr_direct\x18\t \x01(\x01\x12\x1a\n\x12\x61livecounter_front\x18\n \x01(\x01\x12\x16\n\x0e\x63hecksum_front\x18\x0b \x01(\x01\"\x8f\x0b\n\nNeolix_edu\x12=\n\x12\x61\x65\x62_systemstate_11\x18\x01 \x01(\x0b\x32!.apollo.canbus.Aeb_systemstate_11\x12U\n\x1evcu_vehicle_fault_response_201\x18\x02 \x01(\x0b\x32-.apollo.canbus.Vcu_vehicle_fault_response_201\x12?\n\x13vcu_powerstatus_214\x18\x03 \x01(\x0b\x32\".apollo.canbus.Vcu_powerstatus_214\x12M\n\x1a\x61\x64s_light_horn_command_310\x18\x04 \x01(\x0b\x32).apollo.canbus.Ads_light_horn_command_310\x12\x41\n\x14\x61\x64s_brake_command_46\x18\x05 \x01(\x0b\x32#.apollo.canbus.Ads_brake_command_46\x12?\n\x13vcu_brake_report_47\x18\x06 \x01(\x0b\x32\".apollo.canbus.Vcu_brake_report_47\x12;\n\x11vcu_eps_report_57\x18\x07 \x01(\x0b\x32 .apollo.canbus.Vcu_eps_report_57\x12=\n\x12\x61\x64s_eps_command_56\x18\x08 \x01(\x0b\x32!.apollo.canbus.Ads_eps_command_56\x12\x41\n\x14\x61\x64s_drive_command_50\x18\t \x01(\x0b\x32#.apollo.canbus.Ads_drive_command_50\x12?\n\x13vcu_drive_report_52\x18\n \x01(\x0b\x32\".apollo.canbus.Vcu_drive_report_52\x12;\n\x11\x61\x64s_diagnosis_628\x18\x0b \x01(\x0b\x32 .apollo.canbus.Ads_diagnosis_628\x12-\n\nvcu_nm_401\x18\x0c \x01(\x0b\x32\x19.apollo.canbus.Vcu_nm_401\x12S\n\x1dvcu_vehicle_status_report_101\x18\r \x01(\x0b\x32,.apollo.canbus.Vcu_vehicle_status_report_101\x12S\n\x1dvcu_vehicle_info_response_502\x18\x0e \x01(\x0b\x32,.apollo.canbus.Vcu_vehicle_info_response_502\x12=\n\x12\x61\x65\x62_diagnosis1_626\x18\x0f \x01(\x0b\x32!.apollo.canbus.Aeb_diagnosis1_626\x12\x39\n\x10\x61\x65\x62_diagresp_718\x18\x10 \x01(\x0b\x32\x1f.apollo.canbus.Aeb_diagresp_718\x12\x39\n\x10pas_1st_data_311\x18\x11 \x01(\x0b\x32\x1f.apollo.canbus.Pas_1st_data_311\x12\x39\n\x10pas_2nd_data_312\x18\x12 \x01(\x0b\x32\x1f.apollo.canbus.Pas_2nd_data_312\x12\x41\n\x14\x61\x65\x62_wheelimpulse_355\x18\x13 \x01(\x0b\x32#.apollo.canbus.Aeb_wheelimpulse_355\x12\x45\n\x16\x61\x65\x62_rearwheelspeed_354\x18\x14 \x01(\x0b\x32%.apollo.canbus.Aeb_rearwheelspeed_354\x12G\n\x17\x61\x65\x62_frontwheelspeed_353\x18\x15 \x01(\x0b\x32&.apollo.canbus.Aeb_frontwheelspeed_353'
)



_VCU_BRAKE_REPORT_47_CONTROL_MODE_RESPTYPE = _descriptor.EnumDescriptor(
  name='Control_mode_respType',
  full_name='apollo.canbus.Vcu_brake_report_47.Control_mode_respType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_STANDBY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_AUTO_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_NET_DRIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_REMOTE_CONTROL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_EMERGENCY_BRAKE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2073,
  serialized_end=2271,
)
_sym_db.RegisterEnumDescriptor(_VCU_BRAKE_REPORT_47_CONTROL_MODE_RESPTYPE)

_VCU_EPS_REPORT_57_CONTROL_MODE_RESPTYPE = _descriptor.EnumDescriptor(
  name='Control_mode_respType',
  full_name='apollo.canbus.Vcu_eps_report_57.Control_mode_respType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_STANDBY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_AUTO_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_NET_DRIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_REMOTE_CONTROL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_EMERGENCY_BRAKE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2073,
  serialized_end=2271,
)
_sym_db.RegisterEnumDescriptor(_VCU_EPS_REPORT_57_CONTROL_MODE_RESPTYPE)

_ADS_DRIVE_COMMAND_50_AUTO_SHIFT_COMMANDTYPE = _descriptor.EnumDescriptor(
  name='Auto_shift_commandType',
  full_name='apollo.canbus.Ads_drive_command_50.Auto_shift_commandType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO_SHIFT_COMMAND_N', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO_SHIFT_COMMAND_D', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO_SHIFT_COMMAND_R', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO_SHIFT_COMMAND_RESERVED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3183,
  serialized_end=3318,
)
_sym_db.RegisterEnumDescriptor(_ADS_DRIVE_COMMAND_50_AUTO_SHIFT_COMMANDTYPE)

_VCU_DRIVE_REPORT_52_CONTROL_MODE_RESPTYPE = _descriptor.EnumDescriptor(
  name='Control_mode_respType',
  full_name='apollo.canbus.Vcu_drive_report_52.Control_mode_respType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_STANDBY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_AUTO_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_NET_DRIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_REMOTE_CONTROL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_EMERGENCY_BRAKE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2073,
  serialized_end=2271,
)
_sym_db.RegisterEnumDescriptor(_VCU_DRIVE_REPORT_52_CONTROL_MODE_RESPTYPE)

_VCU_DRIVE_REPORT_52_VCU_REAL_SHIFTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_real_shiftType',
  full_name='apollo.canbus.Vcu_drive_report_52.Vcu_real_shiftType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_REAL_SHIFT_N', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_REAL_SHIFT_D', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_REAL_SHIFT_R', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_REAL_SHIFT_RESERVED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3921,
  serialized_end=4036,
)
_sym_db.RegisterEnumDescriptor(_VCU_DRIVE_REPORT_52_VCU_REAL_SHIFTTYPE)

_VCU_VEHICLE_STATUS_REPORT_101_CONTROL_MODE_RESPTYPE = _descriptor.EnumDescriptor(
  name='Control_mode_respType',
  full_name='apollo.canbus.Vcu_vehicle_status_report_101.Control_mode_respType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_STANDBY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_AUTO_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_NET_DRIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_REMOTE_CONTROL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_MODE_RESP_EMERGENCY_BRAKE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2073,
  serialized_end=2271,
)
_sym_db.RegisterEnumDescriptor(_VCU_VEHICLE_STATUS_REPORT_101_CONTROL_MODE_RESPTYPE)


_AEB_SYSTEMSTATE_11 = _descriptor.Descriptor(
  name='Aeb_systemstate_11',
  full_name='apollo.canbus.Aeb_systemstate_11',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aeb_state', full_name='apollo.canbus.Aeb_systemstate_11.aeb_state', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_brakestate', full_name='apollo.canbus.Aeb_systemstate_11.aeb_brakestate', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='faultrank', full_name='apollo.canbus.Aeb_systemstate_11.faultrank', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currenttemperature', full_name='apollo.canbus.Aeb_systemstate_11.currenttemperature', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f1_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_f1_stop', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f2_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_f2_stop', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f3_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_f3_stop', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f4_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_f4_stop', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_b1_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_b1_stop', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_b2_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_b2_stop', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_b3_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_b3_stop', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_b4_stop', full_name='apollo.canbus.Aeb_systemstate_11.pas_b4_stop', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_livecounter_rear', full_name='apollo.canbus.Aeb_systemstate_11.aeb_livecounter_rear', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_cheksum', full_name='apollo.canbus.Aeb_systemstate_11.aeb_cheksum', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=386,
)


_VCU_VEHICLE_FAULT_RESPONSE_201 = _descriptor.Descriptor(
  name='Vcu_vehicle_fault_response_201',
  full_name='apollo.canbus.Vcu_vehicle_fault_response_201',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_error_indicationsvcu', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.vehicle_error_indicationsvcu', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_system_errorehb', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.brake_system_errorehb', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_error', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.eps_error', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motor_error', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.motor_error', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epb_error', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.epb_error', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_voltage_battery_errorbcu', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.high_voltage_battery_errorbcu', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_losscommuni', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_losscommuni', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_reqsignalno', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_reqsignalno', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_low_power', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_low_power', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_highvolt', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_highvolt', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_vehicle_flt', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_vehicle_flt', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_press_emerg', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_press_emerg', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_press_remot', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_press_remot', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automode_exit_reason_pdu_control', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.automode_exit_reason_pdu_control', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_faultrept_alivecounter', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.vcu_faultrept_alivecounter', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_faultrept_checksum', full_name='apollo.canbus.Vcu_vehicle_fault_response_201.vcu_faultrept_checksum', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=987,
)


_VCU_POWERSTATUS_214 = _descriptor.Descriptor(
  name='Vcu_powerstatus_214',
  full_name='apollo.canbus.Vcu_powerstatus_214',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vcu_powermode', full_name='apollo.canbus.Vcu_powerstatus_214.vcu_powermode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_powermodevalid', full_name='apollo.canbus.Vcu_powerstatus_214.vcu_powermodevalid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replacebatterystateindication', full_name='apollo.canbus.Vcu_powerstatus_214.replacebatterystateindication', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forbidden_aeb_signal', full_name='apollo.canbus.Vcu_powerstatus_214.forbidden_aeb_signal', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcu_chargedischargecurrent', full_name='apollo.canbus.Vcu_powerstatus_214.bcu_chargedischargecurrent', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcu_batt_internalvoltage', full_name='apollo.canbus.Vcu_powerstatus_214.bcu_batt_internalvoltage', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_driverinfo_alivecounter', full_name='apollo.canbus.Vcu_powerstatus_214.vcu_driverinfo_alivecounter', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_driverinfo_checksum', full_name='apollo.canbus.Vcu_powerstatus_214.vcu_driverinfo_checksum', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1271,
)


_ADS_LIGHT_HORN_COMMAND_310 = _descriptor.Descriptor(
  name='Ads_light_horn_command_310',
  full_name='apollo.canbus.Ads_light_horn_command_310',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='turn_right_light_command', full_name='apollo.canbus.Ads_light_horn_command_310.turn_right_light_command', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_left_light_command', full_name='apollo.canbus.Ads_light_horn_command_310.turn_left_light_command', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn_command', full_name='apollo.canbus.Ads_light_horn_command_310.horn_command', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beam_command', full_name='apollo.canbus.Ads_light_horn_command_310.beam_command', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_alivecounter', full_name='apollo.canbus.Ads_light_horn_command_310.auto_drivercmd_alivecounter', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_checksum', full_name='apollo.canbus.Ads_light_horn_command_310.auto_drivercmd_checksum', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1274,
  serialized_end=1483,
)


_ADS_BRAKE_COMMAND_46 = _descriptor.Descriptor(
  name='Ads_brake_command_46',
  full_name='apollo.canbus.Ads_brake_command_46',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drive_enable', full_name='apollo.canbus.Ads_brake_command_46.drive_enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_brake_command', full_name='apollo.canbus.Ads_brake_command_46.auto_brake_command', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_parking_command', full_name='apollo.canbus.Ads_brake_command_46.auto_parking_command', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epb_rampauxiliarycommand', full_name='apollo.canbus.Ads_brake_command_46.epb_rampauxiliarycommand', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_alivecounter', full_name='apollo.canbus.Ads_brake_command_46.auto_drivercmd_alivecounter', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_checksum', full_name='apollo.canbus.Ads_brake_command_46.auto_drivercmd_checksum', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1486,
  serialized_end=1692,
)


_VCU_BRAKE_REPORT_47 = _descriptor.Descriptor(
  name='Vcu_brake_report_47',
  full_name='apollo.canbus.Vcu_brake_report_47',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_enable_resp', full_name='apollo.canbus.Vcu_brake_report_47.brake_enable_resp', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_mode_resp', full_name='apollo.canbus.Vcu_brake_report_47.control_mode_resp', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_brake_valid', full_name='apollo.canbus.Vcu_brake_report_47.vcu_real_brake_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_brake', full_name='apollo.canbus.Vcu_brake_report_47.vcu_real_brake', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_parking_status', full_name='apollo.canbus.Vcu_brake_report_47.vcu_real_parking_status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_parking_valid', full_name='apollo.canbus.Vcu_brake_report_47.vcu_real_parking_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rampauxiliaryindication', full_name='apollo.canbus.Vcu_brake_report_47.rampauxiliaryindication', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicleslope', full_name='apollo.canbus.Vcu_brake_report_47.vehicleslope', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_brakerept_alivecounter', full_name='apollo.canbus.Vcu_brake_report_47.vcu_brakerept_alivecounter', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_brakerept_checksum', full_name='apollo.canbus.Vcu_brake_report_47.vcu_brakerept_checksum', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VCU_BRAKE_REPORT_47_CONTROL_MODE_RESPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=2271,
)


_VCU_EPS_REPORT_57 = _descriptor.Descriptor(
  name='Vcu_eps_report_57',
  full_name='apollo.canbus.Vcu_eps_report_57',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drive_enable_resp', full_name='apollo.canbus.Vcu_eps_report_57.drive_enable_resp', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_mode_resp', full_name='apollo.canbus.Vcu_eps_report_57.control_mode_resp', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_eps_report', full_name='apollo.canbus.Vcu_eps_report_57.vcu_eps_report', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_angle', full_name='apollo.canbus.Vcu_eps_report_57.vcu_real_angle', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_angle_valid', full_name='apollo.canbus.Vcu_eps_report_57.vcu_real_angle_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_target_angle_valid', full_name='apollo.canbus.Vcu_eps_report_57.vcu_target_angle_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_target_angle', full_name='apollo.canbus.Vcu_eps_report_57.vcu_target_angle', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_eps_rept_alivecounter', full_name='apollo.canbus.Vcu_eps_report_57.vcu_eps_rept_alivecounter', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_eps_rept_checksum', full_name='apollo.canbus.Vcu_eps_report_57.vcu_eps_rept_checksum', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VCU_EPS_REPORT_57_CONTROL_MODE_RESPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2274,
  serialized_end=2806,
)


_ADS_EPS_COMMAND_56 = _descriptor.Descriptor(
  name='Ads_eps_command_56',
  full_name='apollo.canbus.Ads_eps_command_56',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drive_enable', full_name='apollo.canbus.Ads_eps_command_56.drive_enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_target_angle', full_name='apollo.canbus.Ads_eps_command_56.auto_target_angle', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_alivecounter', full_name='apollo.canbus.Ads_eps_command_56.auto_drivercmd_alivecounter', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_checksum', full_name='apollo.canbus.Ads_eps_command_56.auto_drivercmd_checksum', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2809,
  serialized_end=2948,
)


_ADS_DRIVE_COMMAND_50 = _descriptor.Descriptor(
  name='Ads_drive_command_50',
  full_name='apollo.canbus.Ads_drive_command_50',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drive_enable', full_name='apollo.canbus.Ads_drive_command_50.drive_enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_shift_command', full_name='apollo.canbus.Ads_drive_command_50.auto_shift_command', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drive_torque', full_name='apollo.canbus.Ads_drive_command_50.auto_drive_torque', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_alivecounter', full_name='apollo.canbus.Ads_drive_command_50.auto_drivercmd_alivecounter', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_drivercmd_checksum', full_name='apollo.canbus.Ads_drive_command_50.auto_drivercmd_checksum', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADS_DRIVE_COMMAND_50_AUTO_SHIFT_COMMANDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2951,
  serialized_end=3318,
)


_VCU_DRIVE_REPORT_52 = _descriptor.Descriptor(
  name='Vcu_drive_report_52',
  full_name='apollo.canbus.Vcu_drive_report_52',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drive_enable_resp', full_name='apollo.canbus.Vcu_drive_report_52.drive_enable_resp', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_mode_resp', full_name='apollo.canbus.Vcu_drive_report_52.control_mode_resp', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_shift', full_name='apollo.canbus.Vcu_drive_report_52.vcu_real_shift', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_shift_valid', full_name='apollo.canbus.Vcu_drive_report_52.vcu_real_shift_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_torque_valid', full_name='apollo.canbus.Vcu_drive_report_52.vcu_real_torque_valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_real_torque', full_name='apollo.canbus.Vcu_drive_report_52.vcu_real_torque', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_limitedtorquemode', full_name='apollo.canbus.Vcu_drive_report_52.vcu_limitedtorquemode', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_driverept_alivecounter', full_name='apollo.canbus.Vcu_drive_report_52.vcu_driverept_alivecounter', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_driverept_checksum', full_name='apollo.canbus.Vcu_drive_report_52.vcu_driverept_checksum', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VCU_DRIVE_REPORT_52_CONTROL_MODE_RESPTYPE,
    _VCU_DRIVE_REPORT_52_VCU_REAL_SHIFTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3321,
  serialized_end=4036,
)


_ADS_DIAGNOSIS_628 = _descriptor.Descriptor(
  name='Ads_diagnosis_628',
  full_name='apollo.canbus.Ads_diagnosis_628',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='faultrank', full_name='apollo.canbus.Ads_diagnosis_628.faultrank', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adas_fault_code', full_name='apollo.canbus.Ads_diagnosis_628.adas_fault_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adas_softwareversion', full_name='apollo.canbus.Ads_diagnosis_628.adas_softwareversion', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adas_hardwareversion', full_name='apollo.canbus.Ads_diagnosis_628.adas_hardwareversion', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4038,
  serialized_end=4161,
)


_VCU_NM_401 = _descriptor.Descriptor(
  name='Vcu_nm_401',
  full_name='apollo.canbus.Vcu_nm_401',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vcu_sleepcommand', full_name='apollo.canbus.Vcu_nm_401.vcu_sleepcommand', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4163,
  serialized_end=4201,
)


_VCU_VEHICLE_STATUS_REPORT_101 = _descriptor.Descriptor(
  name='Vcu_vehicle_status_report_101',
  full_name='apollo.canbus.Vcu_vehicle_status_report_101',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drive_enable_resp', full_name='apollo.canbus.Vcu_vehicle_status_report_101.drive_enable_resp', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_highvoltagecircuitstate', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_highvoltagecircuitstate', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_dcdc_enabledstates', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_dcdc_enabledstates', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_mode_resp', full_name='apollo.canbus.Vcu_vehicle_status_report_101.control_mode_resp', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_vehicle_speed', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_vehicle_speed', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_lowbatterychargingfunctionst', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_lowbatterychargingfunctionst', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_display_soc', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_display_soc', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_motor_speed', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_motor_speed', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_motor_direction', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_motor_direction', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_motor_speed_valid', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_motor_speed_valid', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_statusrept_alivecounter', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_statusrept_alivecounter', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_statusrept_checksum', full_name='apollo.canbus.Vcu_vehicle_status_report_101.vcu_statusrept_checksum', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VCU_VEHICLE_STATUS_REPORT_101_CONTROL_MODE_RESPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4204,
  serialized_end=4876,
)


_VCU_VEHICLE_INFO_RESPONSE_502 = _descriptor.Descriptor(
  name='Vcu_vehicle_info_response_502',
  full_name='apollo.canbus.Vcu_vehicle_info_response_502',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_softwareversion_indicati', full_name='apollo.canbus.Vcu_vehicle_info_response_502.vehicle_softwareversion_indicati', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project', full_name='apollo.canbus.Vcu_vehicle_info_response_502.project', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manufacturer', full_name='apollo.canbus.Vcu_vehicle_info_response_502.manufacturer', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='apollo.canbus.Vcu_vehicle_info_response_502.year', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='apollo.canbus.Vcu_vehicle_info_response_502.month', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='apollo.canbus.Vcu_vehicle_info_response_502.day', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_serial_number', full_name='apollo.canbus.Vcu_vehicle_info_response_502.vehicle_serial_number', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4879,
  serialized_end=5064,
)


_AEB_DIAGNOSIS1_626 = _descriptor.Descriptor(
  name='Aeb_diagnosis1_626',
  full_name='apollo.canbus.Aeb_diagnosis1_626',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aeb_softwareversion', full_name='apollo.canbus.Aeb_diagnosis1_626.aeb_softwareversion', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_hardwareversion', full_name='apollo.canbus.Aeb_diagnosis1_626.aeb_hardwareversion', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5066,
  serialized_end=5144,
)


_AEB_DIAGRESP_718 = _descriptor.Descriptor(
  name='Aeb_diagresp_718',
  full_name='apollo.canbus.Aeb_diagresp_718',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aeb_diagresp', full_name='apollo.canbus.Aeb_diagresp_718.aeb_diagresp', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5146,
  serialized_end=5186,
)


_PAS_1ST_DATA_311 = _descriptor.Descriptor(
  name='Pas_1st_data_311',
  full_name='apollo.canbus.Pas_1st_data_311',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pasdistance4', full_name='apollo.canbus.Pas_1st_data_311.pasdistance4', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pasdistance3', full_name='apollo.canbus.Pas_1st_data_311.pasdistance3', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f1_status', full_name='apollo.canbus.Pas_1st_data_311.pas_f1_status', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f2_status', full_name='apollo.canbus.Pas_1st_data_311.pas_f2_status', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f3_status', full_name='apollo.canbus.Pas_1st_data_311.pas_f3_status', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_f4_status', full_name='apollo.canbus.Pas_1st_data_311.pas_f4_status', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pasdistance2', full_name='apollo.canbus.Pas_1st_data_311.pasdistance2', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pasdistance1', full_name='apollo.canbus.Pas_1st_data_311.pasdistance1', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5189,
  serialized_end=5387,
)


_PAS_2ND_DATA_312 = _descriptor.Descriptor(
  name='Pas_2nd_data_312',
  full_name='apollo.canbus.Pas_2nd_data_312',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pas_b1_status', full_name='apollo.canbus.Pas_2nd_data_312.pas_b1_status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_b2_status', full_name='apollo.canbus.Pas_2nd_data_312.pas_b2_status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_b3_status', full_name='apollo.canbus.Pas_2nd_data_312.pas_b3_status', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_b4_status', full_name='apollo.canbus.Pas_2nd_data_312.pas_b4_status', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pasdistance1', full_name='apollo.canbus.Pas_2nd_data_312.pasdistance1', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pasdistance2', full_name='apollo.canbus.Pas_2nd_data_312.pasdistance2', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pasdistance3', full_name='apollo.canbus.Pas_2nd_data_312.pasdistance3', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pasdistance4', full_name='apollo.canbus.Pas_2nd_data_312.pasdistance4', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5390,
  serialized_end=5588,
)


_AEB_WHEELIMPULSE_355 = _descriptor.Descriptor(
  name='Aeb_wheelimpulse_355',
  full_name='apollo.canbus.Aeb_wheelimpulse_355',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flimpulse', full_name='apollo.canbus.Aeb_wheelimpulse_355.flimpulse', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flimpulsevalid', full_name='apollo.canbus.Aeb_wheelimpulse_355.flimpulsevalid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frimpulse', full_name='apollo.canbus.Aeb_wheelimpulse_355.frimpulse', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frimpulsevalid', full_name='apollo.canbus.Aeb_wheelimpulse_355.frimpulsevalid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rlimpulse', full_name='apollo.canbus.Aeb_wheelimpulse_355.rlimpulse', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rlimpulsevalid', full_name='apollo.canbus.Aeb_wheelimpulse_355.rlimpulsevalid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rrimpulse', full_name='apollo.canbus.Aeb_wheelimpulse_355.rrimpulse', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rrimpulsevalid', full_name='apollo.canbus.Aeb_wheelimpulse_355.rrimpulsevalid', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alivecounter', full_name='apollo.canbus.Aeb_wheelimpulse_355.alivecounter', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='apollo.canbus.Aeb_wheelimpulse_355.checksum', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5591,
  serialized_end=5825,
)


_AEB_REARWHEELSPEED_354 = _descriptor.Descriptor(
  name='Aeb_rearwheelspeed_354',
  full_name='apollo.canbus.Aeb_rearwheelspeed_354',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheelspeed_rl_valid', full_name='apollo.canbus.Aeb_rearwheelspeed_354.wheelspeed_rl_valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_rl', full_name='apollo.canbus.Aeb_rearwheelspeed_354.wheelspeed_rl', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_rr_valid', full_name='apollo.canbus.Aeb_rearwheelspeed_354.wheelspeed_rr_valid', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_rr', full_name='apollo.canbus.Aeb_rearwheelspeed_354.wheelspeed_rr', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_rl_direct', full_name='apollo.canbus.Aeb_rearwheelspeed_354.wheelspeed_rl_direct', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_rr_direct', full_name='apollo.canbus.Aeb_rearwheelspeed_354.wheelspeed_rr_direct', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alivecounter_rear', full_name='apollo.canbus.Aeb_rearwheelspeed_354.alivecounter_rear', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum_rear', full_name='apollo.canbus.Aeb_rearwheelspeed_354.checksum_rear', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5828,
  serialized_end=6066,
)


_AEB_FRONTWHEELSPEED_353 = _descriptor.Descriptor(
  name='Aeb_frontwheelspeed_353',
  full_name='apollo.canbus.Aeb_frontwheelspeed_353',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehiclespeedvalid', full_name='apollo.canbus.Aeb_frontwheelspeed_353.vehiclespeedvalid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehiclespeed', full_name='apollo.canbus.Aeb_frontwheelspeed_353.vehiclespeed', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehiclerealdirect', full_name='apollo.canbus.Aeb_frontwheelspeed_353.vehiclerealdirect', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_fl_valid', full_name='apollo.canbus.Aeb_frontwheelspeed_353.wheelspeed_fl_valid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_fl', full_name='apollo.canbus.Aeb_frontwheelspeed_353.wheelspeed_fl', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_fr_valid', full_name='apollo.canbus.Aeb_frontwheelspeed_353.wheelspeed_fr_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_fr', full_name='apollo.canbus.Aeb_frontwheelspeed_353.wheelspeed_fr', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_fl_direct', full_name='apollo.canbus.Aeb_frontwheelspeed_353.wheelspeed_fl_direct', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelspeed_fr_direct', full_name='apollo.canbus.Aeb_frontwheelspeed_353.wheelspeed_fr_direct', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alivecounter_front', full_name='apollo.canbus.Aeb_frontwheelspeed_353.alivecounter_front', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checksum_front', full_name='apollo.canbus.Aeb_frontwheelspeed_353.checksum_front', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6069,
  serialized_end=6386,
)


_NEOLIX_EDU = _descriptor.Descriptor(
  name='Neolix_edu',
  full_name='apollo.canbus.Neolix_edu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aeb_systemstate_11', full_name='apollo.canbus.Neolix_edu.aeb_systemstate_11', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_vehicle_fault_response_201', full_name='apollo.canbus.Neolix_edu.vcu_vehicle_fault_response_201', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_powerstatus_214', full_name='apollo.canbus.Neolix_edu.vcu_powerstatus_214', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_light_horn_command_310', full_name='apollo.canbus.Neolix_edu.ads_light_horn_command_310', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_brake_command_46', full_name='apollo.canbus.Neolix_edu.ads_brake_command_46', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_brake_report_47', full_name='apollo.canbus.Neolix_edu.vcu_brake_report_47', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_eps_report_57', full_name='apollo.canbus.Neolix_edu.vcu_eps_report_57', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_eps_command_56', full_name='apollo.canbus.Neolix_edu.ads_eps_command_56', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_drive_command_50', full_name='apollo.canbus.Neolix_edu.ads_drive_command_50', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_drive_report_52', full_name='apollo.canbus.Neolix_edu.vcu_drive_report_52', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_diagnosis_628', full_name='apollo.canbus.Neolix_edu.ads_diagnosis_628', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_nm_401', full_name='apollo.canbus.Neolix_edu.vcu_nm_401', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_vehicle_status_report_101', full_name='apollo.canbus.Neolix_edu.vcu_vehicle_status_report_101', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_vehicle_info_response_502', full_name='apollo.canbus.Neolix_edu.vcu_vehicle_info_response_502', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_diagnosis1_626', full_name='apollo.canbus.Neolix_edu.aeb_diagnosis1_626', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_diagresp_718', full_name='apollo.canbus.Neolix_edu.aeb_diagresp_718', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_1st_data_311', full_name='apollo.canbus.Neolix_edu.pas_1st_data_311', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pas_2nd_data_312', full_name='apollo.canbus.Neolix_edu.pas_2nd_data_312', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_wheelimpulse_355', full_name='apollo.canbus.Neolix_edu.aeb_wheelimpulse_355', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_rearwheelspeed_354', full_name='apollo.canbus.Neolix_edu.aeb_rearwheelspeed_354', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aeb_frontwheelspeed_353', full_name='apollo.canbus.Neolix_edu.aeb_frontwheelspeed_353', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6389,
  serialized_end=7812,
)

_VCU_BRAKE_REPORT_47.fields_by_name['control_mode_resp'].enum_type = _VCU_BRAKE_REPORT_47_CONTROL_MODE_RESPTYPE
_VCU_BRAKE_REPORT_47_CONTROL_MODE_RESPTYPE.containing_type = _VCU_BRAKE_REPORT_47
_VCU_EPS_REPORT_57.fields_by_name['control_mode_resp'].enum_type = _VCU_EPS_REPORT_57_CONTROL_MODE_RESPTYPE
_VCU_EPS_REPORT_57_CONTROL_MODE_RESPTYPE.containing_type = _VCU_EPS_REPORT_57
_ADS_DRIVE_COMMAND_50.fields_by_name['auto_shift_command'].enum_type = _ADS_DRIVE_COMMAND_50_AUTO_SHIFT_COMMANDTYPE
_ADS_DRIVE_COMMAND_50_AUTO_SHIFT_COMMANDTYPE.containing_type = _ADS_DRIVE_COMMAND_50
_VCU_DRIVE_REPORT_52.fields_by_name['control_mode_resp'].enum_type = _VCU_DRIVE_REPORT_52_CONTROL_MODE_RESPTYPE
_VCU_DRIVE_REPORT_52.fields_by_name['vcu_real_shift'].enum_type = _VCU_DRIVE_REPORT_52_VCU_REAL_SHIFTTYPE
_VCU_DRIVE_REPORT_52_CONTROL_MODE_RESPTYPE.containing_type = _VCU_DRIVE_REPORT_52
_VCU_DRIVE_REPORT_52_VCU_REAL_SHIFTTYPE.containing_type = _VCU_DRIVE_REPORT_52
_VCU_VEHICLE_STATUS_REPORT_101.fields_by_name['control_mode_resp'].enum_type = _VCU_VEHICLE_STATUS_REPORT_101_CONTROL_MODE_RESPTYPE
_VCU_VEHICLE_STATUS_REPORT_101_CONTROL_MODE_RESPTYPE.containing_type = _VCU_VEHICLE_STATUS_REPORT_101
_NEOLIX_EDU.fields_by_name['aeb_systemstate_11'].message_type = _AEB_SYSTEMSTATE_11
_NEOLIX_EDU.fields_by_name['vcu_vehicle_fault_response_201'].message_type = _VCU_VEHICLE_FAULT_RESPONSE_201
_NEOLIX_EDU.fields_by_name['vcu_powerstatus_214'].message_type = _VCU_POWERSTATUS_214
_NEOLIX_EDU.fields_by_name['ads_light_horn_command_310'].message_type = _ADS_LIGHT_HORN_COMMAND_310
_NEOLIX_EDU.fields_by_name['ads_brake_command_46'].message_type = _ADS_BRAKE_COMMAND_46
_NEOLIX_EDU.fields_by_name['vcu_brake_report_47'].message_type = _VCU_BRAKE_REPORT_47
_NEOLIX_EDU.fields_by_name['vcu_eps_report_57'].message_type = _VCU_EPS_REPORT_57
_NEOLIX_EDU.fields_by_name['ads_eps_command_56'].message_type = _ADS_EPS_COMMAND_56
_NEOLIX_EDU.fields_by_name['ads_drive_command_50'].message_type = _ADS_DRIVE_COMMAND_50
_NEOLIX_EDU.fields_by_name['vcu_drive_report_52'].message_type = _VCU_DRIVE_REPORT_52
_NEOLIX_EDU.fields_by_name['ads_diagnosis_628'].message_type = _ADS_DIAGNOSIS_628
_NEOLIX_EDU.fields_by_name['vcu_nm_401'].message_type = _VCU_NM_401
_NEOLIX_EDU.fields_by_name['vcu_vehicle_status_report_101'].message_type = _VCU_VEHICLE_STATUS_REPORT_101
_NEOLIX_EDU.fields_by_name['vcu_vehicle_info_response_502'].message_type = _VCU_VEHICLE_INFO_RESPONSE_502
_NEOLIX_EDU.fields_by_name['aeb_diagnosis1_626'].message_type = _AEB_DIAGNOSIS1_626
_NEOLIX_EDU.fields_by_name['aeb_diagresp_718'].message_type = _AEB_DIAGRESP_718
_NEOLIX_EDU.fields_by_name['pas_1st_data_311'].message_type = _PAS_1ST_DATA_311
_NEOLIX_EDU.fields_by_name['pas_2nd_data_312'].message_type = _PAS_2ND_DATA_312
_NEOLIX_EDU.fields_by_name['aeb_wheelimpulse_355'].message_type = _AEB_WHEELIMPULSE_355
_NEOLIX_EDU.fields_by_name['aeb_rearwheelspeed_354'].message_type = _AEB_REARWHEELSPEED_354
_NEOLIX_EDU.fields_by_name['aeb_frontwheelspeed_353'].message_type = _AEB_FRONTWHEELSPEED_353
DESCRIPTOR.message_types_by_name['Aeb_systemstate_11'] = _AEB_SYSTEMSTATE_11
DESCRIPTOR.message_types_by_name['Vcu_vehicle_fault_response_201'] = _VCU_VEHICLE_FAULT_RESPONSE_201
DESCRIPTOR.message_types_by_name['Vcu_powerstatus_214'] = _VCU_POWERSTATUS_214
DESCRIPTOR.message_types_by_name['Ads_light_horn_command_310'] = _ADS_LIGHT_HORN_COMMAND_310
DESCRIPTOR.message_types_by_name['Ads_brake_command_46'] = _ADS_BRAKE_COMMAND_46
DESCRIPTOR.message_types_by_name['Vcu_brake_report_47'] = _VCU_BRAKE_REPORT_47
DESCRIPTOR.message_types_by_name['Vcu_eps_report_57'] = _VCU_EPS_REPORT_57
DESCRIPTOR.message_types_by_name['Ads_eps_command_56'] = _ADS_EPS_COMMAND_56
DESCRIPTOR.message_types_by_name['Ads_drive_command_50'] = _ADS_DRIVE_COMMAND_50
DESCRIPTOR.message_types_by_name['Vcu_drive_report_52'] = _VCU_DRIVE_REPORT_52
DESCRIPTOR.message_types_by_name['Ads_diagnosis_628'] = _ADS_DIAGNOSIS_628
DESCRIPTOR.message_types_by_name['Vcu_nm_401'] = _VCU_NM_401
DESCRIPTOR.message_types_by_name['Vcu_vehicle_status_report_101'] = _VCU_VEHICLE_STATUS_REPORT_101
DESCRIPTOR.message_types_by_name['Vcu_vehicle_info_response_502'] = _VCU_VEHICLE_INFO_RESPONSE_502
DESCRIPTOR.message_types_by_name['Aeb_diagnosis1_626'] = _AEB_DIAGNOSIS1_626
DESCRIPTOR.message_types_by_name['Aeb_diagresp_718'] = _AEB_DIAGRESP_718
DESCRIPTOR.message_types_by_name['Pas_1st_data_311'] = _PAS_1ST_DATA_311
DESCRIPTOR.message_types_by_name['Pas_2nd_data_312'] = _PAS_2ND_DATA_312
DESCRIPTOR.message_types_by_name['Aeb_wheelimpulse_355'] = _AEB_WHEELIMPULSE_355
DESCRIPTOR.message_types_by_name['Aeb_rearwheelspeed_354'] = _AEB_REARWHEELSPEED_354
DESCRIPTOR.message_types_by_name['Aeb_frontwheelspeed_353'] = _AEB_FRONTWHEELSPEED_353
DESCRIPTOR.message_types_by_name['Neolix_edu'] = _NEOLIX_EDU
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Aeb_systemstate_11 = _reflection.GeneratedProtocolMessageType('Aeb_systemstate_11', (_message.Message,), {
  'DESCRIPTOR' : _AEB_SYSTEMSTATE_11,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Aeb_systemstate_11)
  })
_sym_db.RegisterMessage(Aeb_systemstate_11)

Vcu_vehicle_fault_response_201 = _reflection.GeneratedProtocolMessageType('Vcu_vehicle_fault_response_201', (_message.Message,), {
  'DESCRIPTOR' : _VCU_VEHICLE_FAULT_RESPONSE_201,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_vehicle_fault_response_201)
  })
_sym_db.RegisterMessage(Vcu_vehicle_fault_response_201)

Vcu_powerstatus_214 = _reflection.GeneratedProtocolMessageType('Vcu_powerstatus_214', (_message.Message,), {
  'DESCRIPTOR' : _VCU_POWERSTATUS_214,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_powerstatus_214)
  })
_sym_db.RegisterMessage(Vcu_powerstatus_214)

Ads_light_horn_command_310 = _reflection.GeneratedProtocolMessageType('Ads_light_horn_command_310', (_message.Message,), {
  'DESCRIPTOR' : _ADS_LIGHT_HORN_COMMAND_310,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_light_horn_command_310)
  })
_sym_db.RegisterMessage(Ads_light_horn_command_310)

Ads_brake_command_46 = _reflection.GeneratedProtocolMessageType('Ads_brake_command_46', (_message.Message,), {
  'DESCRIPTOR' : _ADS_BRAKE_COMMAND_46,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_brake_command_46)
  })
_sym_db.RegisterMessage(Ads_brake_command_46)

Vcu_brake_report_47 = _reflection.GeneratedProtocolMessageType('Vcu_brake_report_47', (_message.Message,), {
  'DESCRIPTOR' : _VCU_BRAKE_REPORT_47,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_brake_report_47)
  })
_sym_db.RegisterMessage(Vcu_brake_report_47)

Vcu_eps_report_57 = _reflection.GeneratedProtocolMessageType('Vcu_eps_report_57', (_message.Message,), {
  'DESCRIPTOR' : _VCU_EPS_REPORT_57,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_eps_report_57)
  })
_sym_db.RegisterMessage(Vcu_eps_report_57)

Ads_eps_command_56 = _reflection.GeneratedProtocolMessageType('Ads_eps_command_56', (_message.Message,), {
  'DESCRIPTOR' : _ADS_EPS_COMMAND_56,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_eps_command_56)
  })
_sym_db.RegisterMessage(Ads_eps_command_56)

Ads_drive_command_50 = _reflection.GeneratedProtocolMessageType('Ads_drive_command_50', (_message.Message,), {
  'DESCRIPTOR' : _ADS_DRIVE_COMMAND_50,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_drive_command_50)
  })
_sym_db.RegisterMessage(Ads_drive_command_50)

Vcu_drive_report_52 = _reflection.GeneratedProtocolMessageType('Vcu_drive_report_52', (_message.Message,), {
  'DESCRIPTOR' : _VCU_DRIVE_REPORT_52,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_drive_report_52)
  })
_sym_db.RegisterMessage(Vcu_drive_report_52)

Ads_diagnosis_628 = _reflection.GeneratedProtocolMessageType('Ads_diagnosis_628', (_message.Message,), {
  'DESCRIPTOR' : _ADS_DIAGNOSIS_628,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ads_diagnosis_628)
  })
_sym_db.RegisterMessage(Ads_diagnosis_628)

Vcu_nm_401 = _reflection.GeneratedProtocolMessageType('Vcu_nm_401', (_message.Message,), {
  'DESCRIPTOR' : _VCU_NM_401,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_nm_401)
  })
_sym_db.RegisterMessage(Vcu_nm_401)

Vcu_vehicle_status_report_101 = _reflection.GeneratedProtocolMessageType('Vcu_vehicle_status_report_101', (_message.Message,), {
  'DESCRIPTOR' : _VCU_VEHICLE_STATUS_REPORT_101,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_vehicle_status_report_101)
  })
_sym_db.RegisterMessage(Vcu_vehicle_status_report_101)

Vcu_vehicle_info_response_502 = _reflection.GeneratedProtocolMessageType('Vcu_vehicle_info_response_502', (_message.Message,), {
  'DESCRIPTOR' : _VCU_VEHICLE_INFO_RESPONSE_502,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Vcu_vehicle_info_response_502)
  })
_sym_db.RegisterMessage(Vcu_vehicle_info_response_502)

Aeb_diagnosis1_626 = _reflection.GeneratedProtocolMessageType('Aeb_diagnosis1_626', (_message.Message,), {
  'DESCRIPTOR' : _AEB_DIAGNOSIS1_626,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Aeb_diagnosis1_626)
  })
_sym_db.RegisterMessage(Aeb_diagnosis1_626)

Aeb_diagresp_718 = _reflection.GeneratedProtocolMessageType('Aeb_diagresp_718', (_message.Message,), {
  'DESCRIPTOR' : _AEB_DIAGRESP_718,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Aeb_diagresp_718)
  })
_sym_db.RegisterMessage(Aeb_diagresp_718)

Pas_1st_data_311 = _reflection.GeneratedProtocolMessageType('Pas_1st_data_311', (_message.Message,), {
  'DESCRIPTOR' : _PAS_1ST_DATA_311,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Pas_1st_data_311)
  })
_sym_db.RegisterMessage(Pas_1st_data_311)

Pas_2nd_data_312 = _reflection.GeneratedProtocolMessageType('Pas_2nd_data_312', (_message.Message,), {
  'DESCRIPTOR' : _PAS_2ND_DATA_312,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Pas_2nd_data_312)
  })
_sym_db.RegisterMessage(Pas_2nd_data_312)

Aeb_wheelimpulse_355 = _reflection.GeneratedProtocolMessageType('Aeb_wheelimpulse_355', (_message.Message,), {
  'DESCRIPTOR' : _AEB_WHEELIMPULSE_355,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Aeb_wheelimpulse_355)
  })
_sym_db.RegisterMessage(Aeb_wheelimpulse_355)

Aeb_rearwheelspeed_354 = _reflection.GeneratedProtocolMessageType('Aeb_rearwheelspeed_354', (_message.Message,), {
  'DESCRIPTOR' : _AEB_REARWHEELSPEED_354,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Aeb_rearwheelspeed_354)
  })
_sym_db.RegisterMessage(Aeb_rearwheelspeed_354)

Aeb_frontwheelspeed_353 = _reflection.GeneratedProtocolMessageType('Aeb_frontwheelspeed_353', (_message.Message,), {
  'DESCRIPTOR' : _AEB_FRONTWHEELSPEED_353,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Aeb_frontwheelspeed_353)
  })
_sym_db.RegisterMessage(Aeb_frontwheelspeed_353)

Neolix_edu = _reflection.GeneratedProtocolMessageType('Neolix_edu', (_message.Message,), {
  'DESCRIPTOR' : _NEOLIX_EDU,
  '__module__' : 'modules.canbus.proto.neolix_edu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Neolix_edu)
  })
_sym_db.RegisterMessage(Neolix_edu)


# @@protoc_insertion_point(module_scope)
